Enum Invalidation
pub enum Invalidation {
None,
Overlay,
Layout(Diff),
Widgets,
}Available on crate feature
advanced only.Expand description
The most severe invalidation requested by a Shell while
processing an event.
Variants are ordered by severity and Shell::invalidate
accumulates the maximum: a higher variant subsumes the lower ones.
Variants
None
Nothing needs to be rebuilt.
Overlay
The application overlays need to be recreated.
Layout(Diff)
The application layout needs to be recomputed, following the
given Diff strategy.
Widgets
The entire application widget tree needs to be rebuilt and relaid out.